==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_auv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela ’corcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol dau document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° vèrs la dreita',
	'image_tourner_gauche' => 'Rotacion 90° vèrs la mança',
	'info_document' => 'Document ',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar totes los documents ',
	'info_logo_max_taille' => 'Los lògos an de far mens de @maxi@ (aqueste fichèir fai @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dins l’Internet:',
	'info_telecharger' => 'Telecharjar a partir de vòstre ordenador:',

	// T
	'texte_documents_joints' => 'Podètz autorizar que s’apondan de documents (fichèirs burotics, imatges,
 multimèdia, etc.) aus articles e/o a las rubricas. Aqueles fichèirs
 pòdon puèi èsser referenciats dins
 l’article, o aparéisser d’a part.<p>', # MODIF
	'texte_documents_joints_2' => 'Aquel reglatge empacha pas d’inserir d’imatges dirèctament dins los articles.', # MODIF
	'titre_documents_joints' => 'Documents junts',
	'tout_dossier_upload' => 'Tot lo dorsèir @upload@',

	// U
	'upload_fichier_zip' => 'Fichèir ZIP',
	'upload_fichier_zip_texte' => 'Lo fichèir que prepausatz d’installar z-es un fichèir Zip.',
	'upload_fichier_zip_texte2' => 'Aquel fichèir pòt l-èsser:',
	'upload_limit' => 'Aquel fichèir z-es tròp gròs per lo servidor; la talha maxima autorizada en <i>upload</i> z-es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e chasque element que conten installat sus lo sit. Lendonc los fichèirs que serán installats sus lo sit son:',
	'upload_zip_telquel' => 'installat tau coma z-es, coma archiu comprimit Zip;'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_auv
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela ’corcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol dau document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° vèrs la dreita',
	'image_tourner_gauche' => 'Rotacion 90° vèrs la mança',
	'info_document' => 'Document ',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar totes los documents ',
	'info_logo_max_taille' => 'Los lògos an de far mens de @maxi@ (aqueste fichèir fai @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dins l’Internet:',
	'info_telecharger' => 'Telecharjar a partir de vòstre ordenador:',

	// T
	'texte_documents_joints' => 'Podètz autorizar que s’apondan de documents (fichèirs burotics, imatges,
 multimèdia, etc.) aus articles e/o a las rubricas. Aqueles fichèirs
 pòdon puèi èsser referenciats dins
 l’article, o aparéisser d’a part.<p>', # MODIF
	'texte_documents_joints_2' => 'Aquel reglatge empacha pas d’inserir d’imatges dirèctament dins los articles.', # MODIF
	'titre_documents_joints' => 'Documents junts',
	'tout_dossier_upload' => 'Tot lo dorsèir @upload@',

	// U
	'upload_fichier_zip' => 'Fichèir ZIP',
	'upload_fichier_zip_texte' => 'Lo fichèir que prepausatz d’installar z-es un fichèir Zip.',
	'upload_fichier_zip_texte2' => 'Aquel fichèir pòt l-èsser:',
	'upload_limit' => 'Aquel fichèir z-es tròp gròs per lo servidor; la talha maxima autorizada en <i>upload</i> z-es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e chasque element que conten installat sus lo sit. Lendonc los fichèirs que serán installats sus lo sit son:',
	'upload_zip_telquel' => 'installat tau coma z-es, coma archiu comprimit Zip;',
];
